cunningham\_tables: List of the prime numbers occuring in the Cunningham table
==============================================================================

The script read_cunningham_prime_factors.py was used to generate the
data set from the file http://cage.ugent.be/~jdemeyer/cunningham/main.gz
We include a local copy, main.gz (see comments in the file for details)
